@@ -78,33 +78,26 @@ def get_synchronization_tasks(object_name):
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
                              (~AllTasks.success_one_of("check_current_binhost") |
                              AllTasks.success_all("sync_reps"))),
-                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'
-                 },
-                 {'name': 'set_migration_binhost',
-                  'method': Object('set_migration_host()'),
-                  'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search")|
-                             AllTasks.success_all("sync_reps")),
-                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'on'
                  },
                  # запасная синхронизация, в ходе которой ветки обновляются до
                  # master
-                #  {'name': 'sync_reps_fallback',
-                #   'foreach': 'update.cl_update_sync_rep',
-                #   'message':
-                #       __("Fallback syncing the {eachvar:capitalize} repository"),
-                #   'method': Object('syncRepositories(eachvar,True)'),
-                #   'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
-                #  },
-                #  # обновление переменных информации из binhost
-                #  {'name': 'sync_reps_fallback:update_binhost_list',
-                #   'method': Object('update_binhost_list()'),
-                #   'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
-                #  },
-                #  # найти лучший сервер обновлений 
-                #  {'name': 'sync_reps_fallback:detect_best_binhost',
-                #   'method': Object('detect_best_binhost()'),
-                #   'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
-                #  },
+                 {'name': 'sync_reps_fallback',
+                  'foreach': 'update.cl_update_sync_rep',
+                  'message':
+                      __("Fallback syncing the {eachvar:capitalize} repository"),
+                  'method': Object('syncRepositories(eachvar,True)'),
+                  'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
+                 },
+                 # обновление переменных информации из binhost
+                 {'name': 'sync_reps_fallback:update_binhost_list',
+                  'method': Object('update_binhost_list()'),
+                  'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
+                 },
+                 # найти лучший сервер обновлений 
+                 {'name': 'sync_reps_fallback:detect_best_binhost',
+                  'method': Object('detect_best_binhost()'),
+                  'depend': Tasks.success() & AllTasks.failed_one_of("detect_best_binhost"),
+                 },
                  {'name': 'sync_reps',
                   'foreach': 'update.cl_update_sync_rep',
                   'message': __("Checking {eachvar:capitalize} updates"),
@@ -451,12 +444,10 @@ class ClUpdateAction(Action):
          'depend': Tasks.failed()
          },
         #  #TODO 
-         {'name': 'update:set_current_level',
-         'method': 'Update.update_increment_current_level()',
-         'depend': Tasks.success(), 
-         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off' and
-                Get('update.cl_update_use_migration_host') == 'on'
-         },
+        #  {'name': 'update:set_current_level',
+        #  'method': 'Update.update_set_current_level()',
+        #  'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
+        #  },
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'success_rev',
          'message': __("System update finished!"),
